@@ -188,9 +188,10 @@ class Session(object):
             resource_config,
             stop_condition,
             hyperparameters=None,
-            input_config={},
+            input_config=[],
             env_config=None,
             vpc_config=None,
+            train_retry_when_resource_insufficient=None,
             input_mode="File",
     ):
         """创建训练任务
@@ -267,6 +268,8 @@ class Session(object):
 
             input_mode: 表示输入类型，默认 File。
 
+            train_retry_when_resource_insufficient: (bool), 表示机器资源不够时，将会排队处理。
+
         @返回值: (dict)，创建的训练任务信息，主要包括任务名称
         """
 
@@ -286,6 +289,11 @@ class Session(object):
             "EnvConfig": env_config,
         }
 
+        if train_retry_when_resource_insufficient is True:
+            training_request["RetryWhenResourceInsufficient"] = "Enabled"
+        else:
+            training_request["RetryWhenResourceInsufficient"] = "Disabled"
+
         self.get_ti_client().create_training_job(**training_request)
 
     def stop_training_job(self, job_name):
